@@ -90,16 +90,16 @@ class OriOptimizeEnv(gym.Env):
         self._agent_orientation = self.initial_ori  # 重置环境其实就是将模型的角度摆正，摆回原来的位置
         self.env.getInitialOri(self.initial_ori[0], self.initial_ori[1], self.initial_ori[2])
         self.current_support_volume = self.env.runCompute()
-        _, observation = self._get_obs()
+        observation = self._get_obs()
         info = self._get_info()
         print("reset success")
         # if self.render_mode == "human":
         #     self._render_frame()
 
         if not return_info:
-            return observation
+            return observation.items()
         else:
-            return observation, info
+            return observation.items(), info
 
     def step(self, action):
         angle = self._action_to_direction[action]
@@ -113,8 +113,8 @@ class OriOptimizeEnv(gym.Env):
 
         observation = self._get_obs()
         obs = observation.items()
-        information = self._get_info()
-        info = information.items()
+        info = self._get_info()
+
         print("step forward")
 
         return obs, reward, terminated, False, info
